@@ -1,7 +1,8 @@
 #' Predict gender from Brazilian first names
 #'
 #' @description
-#' \code{get_gender} uses the IBGE's 2010 Census data to predict gender from Brazilian first names.
+#' \code{get_gender} uses the IBGE's Census data to predict gender from Brazilian first names (2010 by default,
+#' optionally 2022).
 #' In particular, the function exploits data on the number of females and males with the same name
 #' in Brazil, or in a given Brazilian state, to calculate the proportion of females using it.
 #'
@@ -14,7 +15,7 @@
 #' Multiple names can be passed to the function call. To speed the calculations,
 #' the package aggregates equal first names to make fewer requests to the IBGE's API.
 #' Also, the package contains an internal dataset with all the names reported by the
-#' IBGE to make faster classifications -- although this option does not support getting results by State.
+#' IBGE to make faster classifications (2010 and 2022), although this option does not support getting results by State.
 #'
 #' @param names A character vector specifying a person's first name. Names can also be passed to the function
 #' as a full name (e.g., Ana Maria de Souza). \code{get_gender} is case insensitive.
@@ -27,8 +28,10 @@
 #' @param internal Use internal data to predict gender? Allowing this option makes
 #' the function faster, but it does not support getting results by State.
 #' Defaults to \code{TRUE}.
-#' @param encoding Encoding used to read Brazilian names and stip accents.
+#' @param encoding Encoding used to read Brazilian names and strip accents.
 #' Defaults to \code{ASCII//TRANSLIT}.
+#' @param year Census year used in the prediction. Supported values are \code{2010}
+#' and \code{2022} (default).
 #'
 #' @section Data:
 #'
@@ -37,6 +40,9 @@
 #' e Estatistica (IBGE). The surveyed population includes 190,8 million Brazilians living in all 27 states.
 #' According to the IBGE, there are more than 130,000 unique first names in this population.
 #'
+#' When \code{year = 2022}, the function queries the IBGE names API with 2022 data or uses the 2022
+#' internal dataset when \code{internal = TRUE} and \code{state} is \code{NULL}.
+#'
 #' @note Names with different spell (e.g., Ana and Anna, or Marcos and Markos) are considered different names.
 #' In addition, only names with more than 20 occurrences, or more than 15 occurrences in a given state,
 #' are included in the IBGE's data.
@@ -77,19 +83,25 @@
 #' # In different states (using API data, must have internet connection)
 #' get_gender(rep('Ana', 3), c('sp', 'am', 'rs'))
 #'  }
+#' 
+#' @import data.table
 #' @export
 
 get_gender <- function(names, state = NULL, prob = FALSE, threshold = 0.9,
-                       internal = TRUE, encoding = "ASCII//TRANSLIT"){
+                       internal = TRUE, encoding = "ASCII//TRANSLIT",
+                       year = 2022){
 
 
   # Inputs
   if(!is.character(encoding)) stop("'encoding' must be a character representing a valid encoding.")
   if(!is.numeric(threshold)) stop("'threshold' must be numeric, between 0 and 1.")
-  if(threshold < 0 | threshold > 1) stop("'threshold' must be between 0 and 1.")
+  if(threshold < 0 || threshold > 1) stop("'threshold' must be between 0 and 1.")
   if(!is.logical(internal)) stop("'internal' must be logical.")
   if(!is.character(names)) stop("'names' must be character.")
   if(!is.logical(prob)) stop("'Prob' must be logical.")
+  if(!is.numeric(year)) stop("'year' must be numeric, either 2010 or 2022.")
+  year <- as.integer(year)
+  if(!year %in% c(2010, 2022)) stop("'year' must be either 2010 or 2022.")
 
 
   # Names
@@ -104,22 +116,23 @@ get_gender <- function(names, state = NULL, prob = FALSE, threshold = 0.9,
 
 
   # Ignore internal when state is declared
-  if(internal & !is.null(state)) internal <- FALSE
+  if(internal && !is.null(state)) internal <- FALSE
 
 
   ### Internal data
-  if(internal) return(get_gender_internal(names, prob, threshold))
+  if(internal) return(get_gender_internal(names, prob, threshold, year))
 
 
   ### API data
   # Whole country & unique names
-  if(is.null(state) & ln == ln_un){
+  if(is.null(state) && ln == ln_un){
 
     # Return
     out <- sapply(1:ln, function(i) get_gender_api(names[i], state,
                                                    prob = prob,
                                                    threshold = threshold,
-                                                   pause = pause))
+                                                   pause = pause,
+                                                   year = year))
     return(out)
   }
 
@@ -130,14 +143,11 @@ get_gender <- function(names, state = NULL, prob = FALSE, threshold = 0.9,
     gender_pred <- sapply(1:ln_un, function(i) get_gender_api(un_names[i], state,
                                                               prob = prob,
                                                               threshold = threshold,
-                                                              pause = pause))
+                                                              pause = pause,
+                                                              year = year))
 
-    # Join
-    names <- dplyr::tibble(names = names)
-    un_names <- dplyr::tibble(names = un_names, prob = gender_pred)
-
-    # Return
-    out <- dplyr::left_join(names, un_names, by = c("names"))$prob
+    # Join with data.table backend
+    out <- gender_pred[match(names, un_names)]
     return(out)
   }
 
@@ -149,32 +159,75 @@ get_gender <- function(names, state = NULL, prob = FALSE, threshold = 0.9,
     out <- sapply(1:ln, function(i) get_gender_api(names[i], state[i],
                                                    prob = prob,
                                                    threshold = threshold,
-                                                   pause = pause))
+                                                   pause = pause,
+                                                   year = year))
     return(out)
   }
 
   # By state & non-unique names
   state <- get_state(state, ln)
-  names <- dplyr::tibble(names = names, state = state)
-  dis_names <- dplyr::distinct(names)
+  dt_names <- data.table::data.table(names = names, state = state)
+  dis_names <- unique(dt_names, by = c("names", "state"))
 
-  dis_names$prob <- sapply(1:length(dis_names$names),
-                           function(i) get_gender_api(dis_names$names[i],
-                                                      dis_names$state[i],
-                                                      prob = prob,
-                                                      threshold = threshold,
-                                                      pause = pause))
-  out <- dplyr::left_join(names, dis_names, by = c("names", "state"))$prob
+  preds <- sapply(seq_len(nrow(dis_names)),
+                  function(i) get_gender_api(dis_names$names[i],
+                                             dis_names$state[i],
+                                             prob = prob,
+                                             threshold = threshold,
+                                             pause = pause,
+                                             year = year))
+
+  dis_names <- data.table::data.table(names = dis_names$names,
+                                      state = dis_names$state,
+                                      prob = preds)
+
+  out <- dis_names[dt_names, on = c("names", "state"), prob]
 
   return(out)
 }
 
 
 # Get individual results from API
-get_gender_api <- function(name, state, prob, threshold, pause = pause){
+get_gender_api <- function(name, state, prob, threshold, pause = FALSE, year = 2010){
 
 
-  # API endpoint
+  if(year == 2022){
+
+    endpoint <- sprintf("https://servicodados.ibge.gov.br/api/v3/nomes/2022/nome/%s", name)
+    localidade <- if(is.null(state)) 0 else state
+
+    response <- get_safe(endpoint, query = list(tipo = "nome", localidade = localidade))
+    if(pause) Sys.sleep(0.3)
+
+    if(is.null(response)) stop("IBGE's API is not responding. Try again later.")
+    httr::stop_for_status(response, task = "retrieve IBGE's API data.")
+
+    content <- httr::content(response, as = "parsed")
+    if(is.list(content) && !is.null(content[[1]]) && is.null(content$homens)) content <- content[[1]]
+
+    homens <- content$homens
+    mulheres <- content$mulheres
+
+    if(is.null(homens) || is.null(mulheres)){
+      if(prob) return(NA_real_)
+      return(as.character(NA))
+    }
+
+    total <- homens + mulheres
+    if(is.na(total) || total == 0){
+      if(prob) return(NA_real_)
+      return(as.character(NA))
+    }
+
+    fprob <- mulheres / total
+    if(prob) return(fprob)
+    return(round_guess(fprob, threshold))
+  }
+
+
+  if(year != 2010) stop("'year' must be either 2010 or 2022.")
+
+  # API endpoint (2010)
   ibge <- "https://servicodados.ibge.gov.br/api/v1/censos/nomes/basica"
 
   # GET
@@ -201,14 +254,19 @@ get_gender_api <- function(name, state, prob, threshold, pause = pause){
 
 
 # Get results from internal data
-get_gender_internal <- function(names, prob, threshold){
+get_gender_internal <- function(names, prob, threshold, year){
 
-  # Join data
-  nms <- dplyr::tibble(nome = names) %>%
-    dplyr::left_join(nomes, by = "nome")
+  # Match probabilities by name without changing return type
+  if(year == 2022 && "prob_fem22" %in% names(nomes)) {
+    probs <- nomes$prob_fem22[match(names, nomes$nome)]
+  } else if(year == 2010 && "prob_fem10" %in% names(nomes)) {
+    probs <- nomes$prob_fem10[match(names, nomes$nome)]
+  } else {
+    probs <- rep(NA_real_, length(names))
+  }
 
   # Return
-  if(prob) return(nms$prob_fem)
-  round_guess(nms$prob_fem, threshold)
+  if(prob) return(probs)
+  as.character(round_guess(probs, threshold))
 }
 
